@@ -1,6 +1,7 @@
 mod boxed_bytes;
 mod code_metadata;
 mod esdt_local_role;
+mod esdt_local_role_flags;
 mod esdt_token_data;
 mod esdt_token_payment;
 mod esdt_token_payment_multi_arg;
@@ -13,6 +14,7 @@ mod token_identifier;
 pub use boxed_bytes::BoxedBytes;
 pub use code_metadata::CodeMetadata;
 pub use esdt_local_role::EsdtLocalRole;
+pub use esdt_local_role_flags::EsdtLocalRoleFlags;
 pub use esdt_token_data::EsdtTokenData;
 pub use esdt_token_payment::EsdtTokenPayment;
 pub use esdt_token_payment_multi_arg::EsdtTokenPaymentMultiArg;
