@@ -2,7 +2,7 @@ use super::BoxedBytes;
 use crate::{
     abi::TypeAbi,
     api::{Handle, ManagedTypeApi},
-    types::{ManagedBuffer, ManagedType},
+    types::{ManagedBuffer, ManagedFrom, ManagedInto, ManagedType},
 };
 use alloc::string::String;
 use elrond_codec::*;
@@ -52,16 +52,18 @@ impl<M: ManagedTypeApi> TokenIdentifier<M> {
 
     pub const DASH_CHARACTER: u8 = b'-';
 
-    pub fn from_esdt_bytes(api: M, bytes: &[u8]) -> Self {
+    #[inline]
+    pub fn from_esdt_bytes<B: ManagedInto<M, ManagedBuffer<M>>>(api: M, bytes: B) -> Self {
         TokenIdentifier {
-            buffer: ManagedBuffer::new_from_bytes(api, bytes),
+            buffer: bytes.managed_into(api),
         }
     }
 
     /// New instance of the special EGLD token representation.
+    #[inline]
     pub fn egld(api: M) -> Self {
         TokenIdentifier {
-            buffer: ManagedBuffer::new_empty(api),
+            buffer: ManagedBuffer::new(api),
         }
     }
 
@@ -176,6 +178,25 @@ impl<M: ManagedTypeApi> From<ManagedBuffer<M>> for TokenIdentifier<M> {
     }
 }
 
+impl<M: ManagedTypeApi> ManagedFrom<M, ManagedBuffer<M>> for TokenIdentifier<M> {
+    #[inline]
+    fn managed_from(_: M, buffer: ManagedBuffer<M>) -> Self {
+        TokenIdentifier::from(buffer)
+    }
+}
+
+impl<M: ManagedTypeApi> ManagedFrom<M, &[u8]> for TokenIdentifier<M> {
+    fn managed_from(api: M, bytes: &[u8]) -> Self {
+        if bytes == Self::EGLD_REPRESENTATION {
+            TokenIdentifier::egld(api)
+        } else {
+            TokenIdentifier {
+                buffer: ManagedBuffer::new_from_bytes(api, bytes),
+            }
+        }
+    }
+}
+
 impl<M: ManagedTypeApi> PartialEq for TokenIdentifier<M> {
     #[inline]
     fn eq(&self, other: &Self) -> bool {
