@@ -43,12 +43,10 @@ where
 impl<M, T> ManagedMultiResultVec<M, T>
 where
     M: ManagedTypeApi + ErrorApi,
-    T: TopEncode,
+    T: ContractCallArg,
 {
     pub fn push(&mut self, item: T) {
-        let serializer = ManagedSerializer::new(self.raw_buffers.type_manager());
-        self.raw_buffers
-            .push(serializer.top_encode_to_managed_buffer(&item));
+        item.push_dyn_arg(self);
     }
 }
 
@@ -149,6 +147,18 @@ where
     }
 }
 
+impl<M, T> DynArgOutput for ManagedMultiResultVec<M, T>
+where
+    M: ManagedTypeApi,
+    T: ContractCallArg,
+{
+    fn push_single_arg<I: TopEncode>(&mut self, item: I) {
+        let serializer = ManagedSerializer::new(self.raw_buffers.type_manager());
+        self.raw_buffers
+            .push(serializer.top_encode_to_managed_buffer(&item));
+    }
+}
+
 impl<M, T> EndpointResult for ManagedMultiResultVec<M, T>
 where
     M: ManagedTypeApi,
